# eric7.WebBrowser.QtHelp.QtHelpDocumentationSettings

Module implementing a class to store the QtHelp documentation settings before being applied to the help engine.

### Global Attributes

None

### Classes

QtHelpDocumentationSettings | Class implementing a temporary store for QtHelp documentation settings.

### Functions

None

## QtHelpDocumentationSettings

Class implementing a temporary store for QtHelp documentation settings.

### Derived from

None

### Class Attributes

None

### Class Methods

None

### Methods

QtHelpDocumentationSettings | Constructor
addDocumentation | Public method to a add a documentation file to the list.
components | Public method to get the list of components.
namespace | Public method to get the namespace defined by a QtHelp file.
namespaceToFilename | Public method to get the namespace to filename mapping.
namespaces | Public method to get the list of namespaces.
removeDocumentation | Public method to remove the documentation of a given namespace.
versions | Public method to get the list of versions.

### Static Methods

applySettings | Static method to apply the changed QtHelp documentation configuration.
readSettings | Static method to read the QtHelp documentation configuration.

#### QtHelpDocumentationSettings (Constructor)

QtHelpDocumentationSettings()

Constructor

#### QtHelpDocumentationSettings.addDocumentation

addDocumentation(filename)

Public method to a add a documentation file to the list.

filename (str)
  name of the documentation file to add

Return:
  flag indicating success

Return Type:
  bool

#### QtHelpDocumentationSettings.components

components()

Public method to get the list of components.

Return:
  list of components

Return Type:
  list of str

#### QtHelpDocumentationSettings.namespace

namespace(filename)

Public method to get the namespace defined by a QtHelp file.

filename (str)
  name of the QtHelp file

Return:
  name of the namespace

Return Type:
  str

#### QtHelpDocumentationSettings.namespaceToFilename

namespaceToFilename()

Public method to get the namespace to filename mapping.

Return:
  dictionary containing the namespace to filename mapping

Return Type:
  dict

#### QtHelpDocumentationSettings.namespaces

namespaces()

Public method to get the list of namespaces.

Return:
  list of namespaces

Return Type:
  list of str

#### QtHelpDocumentationSettings.removeDocumentation

removeDocumentation(namespace)

Public method to remove the documentation of a given namespace.

namespace (str)
  name of the namespace

Return:
  flag indicating success

Return Type:
  bool

#### QtHelpDocumentationSettings.versions

versions()

Public method to get the list of versions.

Return:
  list of versions

Return Type:
  list of QVersionNumber

#### QtHelpDocumentationSettings.applySettings (static)

applySettings(settings)

Static method to apply the changed QtHelp documentation configuration.

helpEngine (QHelpEngineCore)
  reference to the QtHelp engine
settings (QtHelpDocumentationSettings)
  reference to the created QtHelpDocumentationSettings object

Return:
  flag indicating success

Return Type:
  bool

#### QtHelpDocumentationSettings.readSettings (static)

readSettings()

Static method to read the QtHelp documentation configuration.

helpEngine (QHelpEngineCore)
  reference to the QtHelp engine

Return:
  reference to the created QtHelpDocumentationSettings object

Return Type:
  QtHelpDocumentationSettings

Up